raise DeprecationWarning(
    "This library has been renamed to `eth-utils`.  The `ethereum-utils` "
    "package will no longer recieve updates.  Please update your dependencies "
    "accordingly."
)
